extract_signal: Extract raw signal from PamChip image

Description Usage Arguments Value

View source: R/circles.R

Description

function to extract raw signal of each peptide, left and right controls and 8 background points.

Usage

1
extract_signal(centers.coords, img, radius = 5, parallel = FALSE)

Arguments

centers.coords

data frame of coordinates of centers obtained from the find_centers function.

img

Pamgene image.

radius

the number of pixels to take from the center to build the circle (default 5).

parallel

Parallelize to process to fasten the output.

Value

Returns a data frame with the basic statistics values of all pixels in the circle (mean, median, sum ad sd) of each peptides, left ans right controls and 8 background points.


amelbek/pamgeneAnalyzeR documentation built on May 29, 2019, 8:30 a.m.