mergeExperiments: merge experiments

Description Usage Arguments Value

View source: R/pamgeneObject_class.R

Description

This function merge all experiments (from extracted signal files) in a directory in a data frame with peptides in columns and samples in rows. It also adds as columns the metadata chipID , well, cylce and exposure time.

Usage

1
mergeExperiments(path, pattern = NULL, value = "median")

Arguments

path

the path for the directory where the .txt experiments file obtained from signal exptraction are.

pattern

an optional regular expression. Only files names which match the regular expression will be used. if NULL all files in the directory will be used (default NULL).

value

The value from the extracted signal files to be used. "median", "mean" or "sum" (default "median").

Value

Return a data frame with with chipID , well, cylce exposure time and petides in columns and samples in rows.


amelbek/pamgeneAnalyzeR documentation built on May 29, 2019, 8:30 a.m.