Description Usage Arguments Value
function to extract raw signal of each peptide, left and right controls and 8 background points.
1 | extract_signal(centers.coords, img, radius = 5, parallel = FALSE)
|
centers.coords |
data frame of coordinates of centers obtained from the |
img |
Pamgene image. |
radius |
the number of pixels to take from the center to build the circle (default 5). |
parallel |
Parallelize to process to fasten the output. |
Returns a data frame with the basic statistics values of all pixels in the circle (mean, median, sum ad sd) of each peptides, left ans right controls and 8 background points.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.